pub fn handle() -> &'static PluginLanguagesHandleExpand description
The process-wide handle. See the module docs for why reads do not take one explicitly.
pub fn handle() -> &'static PluginLanguagesHandleThe process-wide handle. See the module docs for why reads do not take one explicitly.