syntax_element_id

Function syntax_element_id 

pub fn syntax_element_id(ids: &BuiltinElementIds, style: Style) -> ElementId
Map a Style syntax category to its builtin syntax.* [ElementId]. The single source of the syntax→element mapping, shared by the cell builder, both renderers’ display-line paths, and the diff overlay.